Refrain from using compiler __atomic_xxx builtins DPDK now requires
the use of rte_atomic_<op>_explicit macros when operating on DPDK
atomic variables.

Signed-off-by: Tyler Retzlaff <roret...@linux.microsoft.com>
Suggested-by: Morten Brørup <m...@smartsharesystems.com>
Acked-by: Bruce Richardson <bruce.richard...@intel.com>
Acked-by: Morten Brørup <m...@smartsharesystems.com>
Acked-by: Konstantin Ananyev <konstantin.v.anan...@yandex.ru>
---
 devtools/checkpatches.sh | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/devtools/checkpatches.sh b/devtools/checkpatches.sh
index 43f5e36..3f051f5 100755
--- a/devtools/checkpatches.sh
+++ b/devtools/checkpatches.sh
@@ -102,20 +102,20 @@ check_forbidden_additions() { # <patch>
                -f $(dirname $(readlink -f $0))/check-forbidden-tokens.awk \
                "$1" || res=1
 
        # refrain from using compiler __atomic_thread_fence()
        # It should be avoided on x86 for SMP case.
        awk -v FOLDERS="lib drivers app examples" \
-               -v EXPRESSIONS="__atomic_thread_fence\\\(" \
+               -v EXPRESSIONS="__rte_atomic_thread_fence\\\(" \
                -v RET_ON_FAIL=1 \
-               -v MESSAGE='Using __atomic_thread_fence' \
+               -v MESSAGE='Using __rte_atomic_thread_fence, prefer 
rte_atomic_thread_fence' \
                -f $(dirname $(readlink -f $0))/check-forbidden-tokens.awk \
                "$1" || res=1
 
-       # refrain from using compiler __atomic_{add,and,nand,or,sub,xor}_fetch()
+       # refrain from using compiler __atomic_xxx builtins
        awk -v FOLDERS="lib drivers app examples" \
-               -v EXPRESSIONS="__atomic_(add|and|nand|or|sub|xor)_fetch\\\(" \
+               -v EXPRESSIONS="__atomic_.*\\\(" \
                -v RET_ON_FAIL=1 \
-               -v MESSAGE='Using __atomic_op_fetch, prefer __atomic_fetch_op' \
+               -v MESSAGE='Using __atomic_xxx built-ins, prefer 
rte_atomic_xxx' \
                -f $(dirname $(readlink -f $0))/check-forbidden-tokens.awk \
                "$1" || res=1
@@ -102,20 +102,20 @@ check_forbidden_additions() { # <patch>
                "$1" || res=1
 
-       # refrain from using compiler __atomic_thread_fence()
+       # refrain from using compiler __rte_atomic_thread_fence()
        # It should be avoided on x86 for SMP case.
        awk -v FOLDERS="lib drivers app examples" \
 
-- 
1.8.3.1

Reply via email to